home · contact · privacy
Use minor mode for plomvi return, default key C-c C-c C-c but customizable.
authorChristian Heller <c.heller@plomlompom.de>
Wed, 11 Sep 2019 00:43:42 +0000 (02:43 +0200)
committerChristian Heller <c.heller@plomlompom.de>
Wed, 11 Sep 2019 00:43:42 +0000 (02:43 +0200)
plomvi.el

index 70903b31b5580be28a74c8dabec4aebc4c64b7ac..28ede5060381314bbf3d3781146366e46a1aead4 100644 (file)
--- a/plomvi.el
+++ b/plomvi.el
 
 ;;; Instructions:
 
-;; 1. load this script into your init file: (load ...)
+;; 1. load this script at the end of your init file: (load ...)
 
-;; 2. to start plomvi by default, put this into your init file:
+;; 2. to start plomvi by default, put this right after:
 ;; (plomvi-global-mode 1)
 
;; 3. define some otherwise unused keybinding to simulate what would
;; be a jump back from Insert mode to Normal mode in Vim (but is de
;; facto just a plomvi mode activation), such as this:
;; (global-set-key (kbd "<f1>") 'plomvi-activate)
 
 
 
@@ -330,3 +332,13 @@ or, on editable buffers, `plomvi-mode-editable'. The latter two's values in
                                          plomvi-mode-basic-map))
 (add-to-list 'minor-mode-map-alist (cons 'plomvi-mode-editable
                                          plomvi-mode-editable-map))
+
+(defvar plomvi-callable-mode-map
+  (let ((map (make-sparse-keymap))
+        (return-combo (if (boundp 'plomvi-return-combo)
+                          plomvi-return-combo
+                        (kbd "C-c C-c C-c"))))
+    (define-key map return-combo 'plomvi-activate)
+    map))
+(define-minor-mode plomvi-callable-mode ""
+  :init-value t :keymap "plomvi-callable")
@@
 ;; (plomvi-global-mode 1)
 
-;; 3. define some otherwise unused keybinding to simulate what would
-;; be a jump back from Insert mode to Normal mode in Vim (but is de
-;; facto just a plomvi mode activation), such as this:
-;; (global-set-key (kbd "<f1>") 'plomvi-activate)
+;; 3. if you want to use a different keybinding than "C-c C-c C-c"
+;; to simulate the jump back from Insert to Normal mode in Vim (de
+;; facto just a plomvi mode activation), put a line such as this
+;; before the (load ...) line for plomvi (with "C-c" the desired
+;; combo):
+;; (defvar plomvi-return-combo (kbd "C-c"))
 
 